==> image_sizes-8.x-1.3.tar.gz: image_sizes/src/Plugin/ImageEffect/InsertStyleEffect.php <==
<?php

namespace Drupal\image_sizes\Plugin\ImageEffect;

use Drupal\image\Entity\ImageStyle;
use Drupal\Core\Image\ImageInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\image\ConfigurableImageEffectBase;

/**
 * Crops an image resource.
 *
 * @ImageEffect(
 *   id = "image_sizes_insert",
 *   label = @Translation("Insert image style"),
 *   description = @Translation("Resizing will make images an exact set of dimensions. This may cause images to be stretched or shrunk disproportionately.")
 * )
 */
class InsertStyleEffect extends ConfigurableImageEffectBase {

  /**
   * {@inheritdoc}
   */
  public function applyEffect(ImageInterface $image) {
    $style = \Drupal::entityTypeManager()->getStorage('image_style')->load($this->configuration['style']);
    foreach ($style->getEffects() as $effect) {
      if ($effect->applyEffect($image) !== true) {
        return false;
      }
    }
    return true;
  }

  /**
   * {@inheritdoc}
   */
  public function getSummary() {
    $summary = [
      '#theme' => 'image_sizes_insert_summary',
      '#data' => $this->configuration,
    ];
    $summary += parent::getSummary();

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      'style' => null,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $options = image_style_options();
    unset($options[$this->getPluginId()]);
    $form['style'] = [
      '#type' => 'select',
      '#title' => t('Image style'),
      '#required' => true,
      '#options' =>  image_style_options(),
      '#default_value' => $this->configuration['style'],
      '#description' => t('The part of the image that will be retained during the crop.'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);

    $this->configuration['style'] = $form_state->getValue('style');
  }

}

==> image_sizes-8.x-1.5.tar.gz: image_sizes/src/Plugin/ImageEffect/InsertStyleEffect.php <==
<?php

namespace Drupal\image_sizes\Plugin\ImageEffect;

use Drupal\image\Entity\ImageStyle;
use Drupal\Core\Image\ImageInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\image\ConfigurableImageEffectBase;

/**
 * Crops an image resource.
 *
 * @ImageEffect(
 *   id = "image_sizes_insert",
 *   label = @Translation("Insert image style"),
 *   description = @Translation("Resizing will make images an exact set of dimensions. This may cause images to be stretched or shrunk disproportionately.")
 * )
 */
class InsertStyleEffect extends ConfigurableImageEffectBase {

  /**
   * {@inheritdoc}
   */
  public function applyEffect(ImageInterface $image) {
    $style = $this->failSafeGetImageStyle($this->configuration['style']);
    if ($style === false) {
      return false;
    }
    foreach ($style->getEffects() as $effect) {
      if ($effect->applyEffect($image) !== true) {
        return false;
      }
    }
    return true;
  }

  /**
   * {@inheritdoc}
   */
  public function getSummary() {
    $summary = [
      '#theme' => 'image_sizes_insert_summary',
      '#data' => $this->configuration,
    ];
    $summary += parent::getSummary();

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      'style' => null,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    $image_styles = [];
    if ($style = $this->failSafeGetImageStyle($this->configuration['style'])) {
      $image_styles[] = $style->getConfigDependencyName();
    }
    return ['config' => $image_styles];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $options = image_style_options();
    unset($options[$this->getPluginId()]);
    $form['style'] = [
      '#type' => 'select',
      '#title' => t('Image style'),
      '#required' => true,
      '#options' =>  image_style_options(),
      '#default_value' => $this->configuration['style'],
      '#description' => t('The part of the image that will be retained during the crop.'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);

    $this->configuration['style'] = $form_state->getValue('style');
  }

  protected function failSafeGetImageStyle($image_style_name) {
    if ($image_style_name === NULL) {
      return NULL;
    }
    $image_style = ImageStyle::load($image_style_name);
    if ($image_style === NULL) {
      // Required style has gone missing?
      $this->logger->error("Cannot find image style '%style_name' to execute an 'insert image style' effect.", ['%style_name' => $image_style_name]);
      return FALSE;
    }
    return $image_style;
  }


}
